require_relative './lib/png_comparison'
require 'optparse'

module CliRunner
  def self.run
    options = {}
    opt_parser = OptionParser.new do |opts|
      opts.banner = "The arguments should be: \n --file1 [path/]img1.png  --file2 [path/]img2.png --diff-file [path/]diff.png\
                                                      --threshold [threshold in percents], [path] can be absolute or relative"
      opts.on('-h', '--help', 'Prints this help') do
        puts opts
        exit
      end
      opts.on( '--file1 file_name', "[file_name] can be either absolute or relative") do |file1|
        options[:file1] = file1
      end
      opts.on('--file2 file_name', "[file_name] can be either absolute or relative") do |file2|
        options[:file2] = file2
      end
      opts.on('-d', '--diff-file diff_file_name', 'default is diff_file.png') do |diff_file|
        options[:diff_file] = diff_file
      end
      opts.on('-t', '--threshold diff_file_name', 'default is diff_file.png') do |threshold|
        options[:threshold] = threshold
      end
    end

    opt_parser.parse!(ARGV)
    if options.key?(:file1) && options.key?(:file2) && options.key?(:diff_file) && options.key?(:threshold)
      img1 = options[:file1] # base image
      img2 = options[:file2] # actual image
      diff_file = options[:diff_file] # difference image
      threshold = options[:threshold] # absolute threshold
      PNG_Comparison::compare(img1: img1, img2: img2, diff_file: diff_file, threshold: threshold)
    else
      puts "Error: not all the mandatory parameters set. please run with -h/--help option"
    end
  end

  CliRunner.run if $PROGRAM_NAME == __FILE__
end